==> item-descriptions-2.5.6%2B1.21.1-fabric-sources.jar: cc/cassian/item_descriptions/client/mixin/EnchantmentScreenMixin.java <==
package cc.cassian.item_descriptions.client.mixin;

import cc.cassian.item_descriptions.client.DescriptionKey;
import cc.cassian.item_descriptions.client.ModClient;
import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import cc.cassian.item_descriptions.client.helpers.ModStyle;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

import java.util.List;
import java.util.Optional;
import net.minecraft.class_1887;
import net.minecraft.class_2561;
import net.minecraft.class_2588;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_486;
import net.minecraft.class_6880;

@Mixin(class_486.class)
public class EnchantmentScreenMixin {
    //? if >1.21.5 {
    /*@WrapOperation(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;setComponentTooltipForNextFrame(Lnet/minecraft/client/gui/Font;Ljava/util/List;II)V"))
       *///?} else if >1.20 {
       @WrapOperation(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderComponentTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;II)V"))
   //?} else {
    /*@WrapOperation(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/screens/inventory/EnchantmentScreen;renderComponentTooltip(Lcom/mojang/blaze3d/vertex/PoseStack;Ljava/util/List;II)V"))
     *///?}
    private void addEnchantmentDescriptions(
            //? if >1.20 {
            class_332 instance, class_327 textRenderer
            //?} else {
            /*EnchantmentScreen instance, PoseStack textRenderer
            *///?}
            , List<class_2561> components, int mouseX, int mouseY, Operation<Void> original, @Local
    //? if >=1.21 {
     Optional<class_6880.class_6883<class_1887>> optional
       //?} else {
       /*Enchantment enchantment
       *///?}
    ) {
        if (//? if >=1.21 {
             optional.isPresent() &&
             //?}
         ModHelpers.showEnchantmentDescriptions() && ModClient.CONFIG.enchantmentDescriptions.enchantingTable.value()) {
            class_2561 name =
            //? if >=1.21 {
             class_1887.method_8179(optional.get(), 1);
            //?} else {
            /*enchantment.getFullname(1);
            *///?}
            if (name.method_10851() instanceof class_2588 content) {
                List<class_2561> tooltip = ModHelpers.createTooltip(name, new DescriptionKey(content.method_11022()).toText().method_10862(ModStyle.ENCHANTMENT_DESCRIPTIONS), true);
                components.addAll(tooltip);
            }
        }
        original.call(instance, textRenderer, components, mouseX, mouseY);
    }
}

==> item-descriptions-2.5.8%2B1.21.10-fabric-sources.jar: cc/cassian/item_descriptions/client/mixin/EnchantmentScreenMixin.java <==
package cc.cassian.item_descriptions.client.mixin;

import cc.cassian.item_descriptions.client.DescriptionKey;
import cc.cassian.item_descriptions.client.ModClient;
import cc.cassian.item_descriptions.client.helpers.ModHelpers;
import cc.cassian.item_descriptions.client.helpers.ModStyle;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

import java.util.List;
import java.util.Optional;
import net.minecraft.class_1887;
import net.minecraft.class_2561;
import net.minecraft.class_2588;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_486;
import net.minecraft.class_6880;

@Mixin(class_486.class)
public class EnchantmentScreenMixin {
    //? if >1.21.5 {
    @WrapOperation(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;setComponentTooltipForNextFrame(Lnet/minecraft/client/gui/Font;Ljava/util/List;II)V"))
    //?} else {
    /*@WrapOperation(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/GuiGraphics;renderComponentTooltip(Lnet/minecraft/client/gui/Font;Ljava/util/List;II)V"))
   *///?}
    private void addEnchantmentDescriptions(class_332 instance, class_327 textRenderer, List<class_2561> components, int mouseX, int mouseY, Operation<Void> original, @Local Optional<class_6880.class_6883<class_1887>> optional
    ) {
        if (optional.isPresent() && ModHelpers.showEnchantmentDescriptions() && ModClient.CONFIG.enchantmentDescriptions.enchantingTable.value()) {
            class_2561 name =
            class_1887.method_8179(optional.get(), 1);
            if (name.method_10851() instanceof class_2588 content) {
                List<class_2561> tooltip = ModHelpers.createTooltip(name, new DescriptionKey(content.method_11022()).toText().method_10862(ModStyle.ENCHANTMENT_DESCRIPTIONS), true);
                components.addAll(tooltip);
            }
        }
        original.call(instance, textRenderer, components, mouseX, mouseY);
    }
}
